<template>
  <div class="mod-config">
    <basic-container>
      <ttable
        :table="table"
        @handleSelectionChange="handleSelectionChange"
        :uploadInfo="uploadInfo"
        :prelang="prelang"
        :options="options"
        :bottomOffset="250"
        :ajaxFun="ajaxFun"
        ref="checkDetailTable"
        :paramObj="paramObj"
      >
        <template #toolbar></template>
      </ttable>
      <!-- 弹窗, 新增 / 修改 -->
      <table-form
        v-if="addOrUpdateVisible"
        ref="addOrUpdate"
        @refreshDataList="getData"
      ></table-form>
    </basic-container>
  </div>
</template>

<script>
import {
  delObjCheckDetail,
  fetchListCheckDetail
} from '@/api/warehouse/checkmain'
import TableForm from './checkdetail-form'
import ttable from '@/views/common/ztt-table.vue'
import { mapGetters } from 'vuex'

export default {
  props: {
    paramObj: {
      type: Object,
      default: () => {
        return {}
      }
    },
    visible: {
      type: Boolean,
      default: false
    },
    checkStatus: {
      type: String,
      default: null
    }
  },
  data() {
    return {
      ajaxFun: fetchListCheckDetail,
      multipleSelection: [],
      isShowQuery: false,
      uploadInfo: {
        // 是否展示上传EXCEL以及对应的url
        isShow: false,
        url: ''
      },
      prelang: 'operation',
      options: {
        height: 300, // 默认高度-为了表头固定
        stripe: true, // 是否为斑马纹 table
        highlightCurrentRow: false, // 是否要高亮当前行
        border: true, // 是否有纵向边框
        lazy: false, // 是否需要懒加载
        fit: true, // 列的宽度是否自撑开
        multiSelect: true, //
        seqNo: true,
        isRefresh: true, // 是否显示刷新按钮
        isShowHide: true, // 是否显示显影按钮
        isSearch: false, // 高级查询按钮
        defaultOrderBy: { column: 'partBatchNo', direction: 'desc' }
      },
      table: {
        total: 0,
        currentPage: 1,
        pageSize: 20,
        data: [],
        // 标题
        column: [
          // 零件
          {
            minWidth: '140',
            prop: 'partNo',
            label: '零件',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text',
            render: { fun: this.addOrUpdateHandle }
          },
          // 零件批号
          {
            minWidth: '120',
            prop: 'partBatchNo',
            label: '零件批号',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          // 库位
          {
            minWidth: '200',
            prop: 'locNo',
            label: '库位号',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          // 库存数量
          {
            minWidth: '140',
            prop: 'locQty',
            label: '库存数量',
            sort: true,
            isTrue: true,
            isSearch: false,
            searchInfoType: 'text'
          },
          // 单位
          {
            minWidth: '120',
            prop: 'unit',
            label: '单位',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          // 盘点数量
          {
            minWidth: '140',
            prop: 'chkQty',
            label: '盘点数量',
            sort: true,
            isTrue: true,
            isSearch: false,
            searchInfoType: 'text'
          },
          // 盘点差异数量
          {
            minWidth: '120',
            prop: 'chkDiffQty',
            label: '盘点差异数量',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          // 状态
          {
            minWidth: '120',
            prop: 'status',
            label: '状态',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          }
        ],
        operator: [],
        operatorConfig: {
          fixed: 'right',
          label: '操作',
          width: 200,
          minWidth: 100
        }
      },
      addOrUpdateVisible: false
    }
  },
  components: {
    ttable,
    TableForm
  },
  computed: {
    ...mapGetters(['permissions'])
  },
  watch: {
    visible: {
      handler(newValue, oldValue) {
        if (newValue) {
          this.getData()
        }
      },
      immediate: true
    },
    checkStatus: {
      handler(newValue, oldValue) {
        if (newValue == '未下发') {
          this.table.operator = [
            {
              text: '删除',
              type: 'text',
              size: 'small',
              fun: this.deleteHandle
            }
          ]
        } else {
          this.table.operator = null
          this.table.toolbar = null
        }
      },
      immediate: true
    }
  },
  methods: {
    // 获取数据列表
    getData() {
      if (this.$refs.checkDetailTable != undefined) {
        this.$refs.checkDetailTable.getDataList()
      }
    },
    handleSelectionChange(val) {
      this.multipleSelection = val
    },
    // 新增 / 修改
    addOrUpdateHandle(row) {
      this.addOrUpdateVisible = true
      this.$nextTick(() => {
        this.$refs.addOrUpdate.init(
          row == null ? null : row.id,
          this.checkStatus
        )
      })
    },
    // 删除
    deleteHandle(row) {
      this.$confirm('是否确认删除ID为' + row.id, '提示', {
        confirmButtonText: '确定',
        cancelButtonText: '取消',
        type: 'warning'
      })
        .then(function() {
          return delObjCheckDetail(row.id)
        })
        .then((data) => {
          this.$message.success('删除成功')
          this.getData()
        })
    }
  }
}
</script>
